package com.facebook.react.uimanager;

import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import com.facebook.common.logging.FLog;
import com.facebook.infer.annotation.Assertions;
import com.facebook.react.common.ReactConstants;
import com.facebook.react.uimanager.TouchTargetHelper;
import com.facebook.react.uimanager.events.EventDispatcher;
import com.facebook.react.uimanager.events.PointerEvent;
import com.facebook.react.uimanager.events.PointerEventHelper;
import com.facebook.react.uimanager.events.TouchEventCoalescingKeyHelper;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

public class JSPointerDispatcher {
    private static final float ONMOVE_EPSILON = 1.0f;
    private int mChildHandlingNativeGesture = -1;
    private long mDownStartTime = Long.MIN_VALUE;
    private long mHoverInteractionKey = Long.MIN_VALUE;
    private final float[] mLastEventCoordinates = new float[2];
    private List<TouchTargetHelper.ViewTarget> mLastHitPath = Collections.emptyList();
    private final ViewGroup mRootViewGroup;
    private final float[] mTargetCoordinates = new float[2];
    private final TouchEventCoalescingKeyHelper mTouchEventCoalescingKeyHelper = new TouchEventCoalescingKeyHelper();

    public JSPointerDispatcher(ViewGroup viewGroup) {
        this.mRootViewGroup = viewGroup;
    }

    public void onChildStartedNativeGesture(View view, MotionEvent motionEvent, EventDispatcher eventDispatcher) {
        if (this.mChildHandlingNativeGesture == -1 && view != null) {
            dispatchCancelEvent(TouchTargetHelper.findTargetPathAndCoordinatesForTouch(motionEvent.getX(), motionEvent.getY(), this.mRootViewGroup, this.mTargetCoordinates), motionEvent, eventDispatcher);
            this.mChildHandlingNativeGesture = view.getId();
        }
    }

    public void onChildEndedNativeGesture() {
        this.mChildHandlingNativeGesture = -1;
    }

    public void handleMotionEvent(MotionEvent motionEvent, EventDispatcher eventDispatcher) {
        boolean supportsHover = PointerEventHelper.supportsHover(motionEvent.getToolType(motionEvent.getActionIndex()));
        int surfaceId = UIManagerHelper.getSurfaceId(this.mRootViewGroup);
        int actionMasked = motionEvent.getActionMasked();
        List<TouchTargetHelper.ViewTarget> findTargetPathAndCoordinatesForTouch = TouchTargetHelper.findTargetPathAndCoordinatesForTouch(motionEvent.getX(), motionEvent.getY(), this.mRootViewGroup, this.mTargetCoordinates);
        if (!findTargetPathAndCoordinatesForTouch.isEmpty()) {
            int viewId = findTargetPathAndCoordinatesForTouch.get(0).getViewId();
            if (supportsHover) {
                if (actionMasked == 7) {
                    handleHoverEvent(motionEvent, eventDispatcher, surfaceId, findTargetPathAndCoordinatesForTouch);
                    return;
                } else if (actionMasked == 10 || actionMasked == 9) {
                    return;
                }
            }
            if (actionMasked == 0) {
                this.mChildHandlingNativeGesture = -1;
                long eventTime = motionEvent.getEventTime();
                this.mDownStartTime = eventTime;
                this.mTouchEventCoalescingKeyHelper.addCoalescingKey(eventTime);
                if (!supportsHover) {
                    int size = findTargetPathAndCoordinatesForTouch.size();
                    while (true) {
                        int i = size - 1;
                        if (size <= 0) {
                            break;
                        }
                        eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_ENTER, surfaceId, findTargetPathAndCoordinatesForTouch.get(i).getViewId(), motionEvent));
                        size = i;
                    }
                }
                eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_DOWN, surfaceId, viewId, motionEvent));
            } else if (this.mChildHandlingNativeGesture == -1) {
                if (actionMasked == 5) {
                    this.mTouchEventCoalescingKeyHelper.incrementCoalescingKey(this.mDownStartTime);
                    eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_DOWN, surfaceId, viewId, motionEvent));
                } else if (actionMasked == 2) {
                    eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_MOVE, surfaceId, viewId, motionEvent, this.mTouchEventCoalescingKeyHelper.getCoalescingKey(this.mDownStartTime)));
                } else if (actionMasked == 6) {
                    this.mTouchEventCoalescingKeyHelper.incrementCoalescingKey(this.mDownStartTime);
                    eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_UP, surfaceId, viewId, motionEvent));
                } else if (actionMasked == 1) {
                    this.mTouchEventCoalescingKeyHelper.removeCoalescingKey(this.mDownStartTime);
                    this.mDownStartTime = Long.MIN_VALUE;
                    eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_UP, surfaceId, viewId, motionEvent));
                    if (!supportsHover) {
                        for (int i2 = 0; i2 < findTargetPathAndCoordinatesForTouch.size(); i2++) {
                            eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_LEAVE, surfaceId, findTargetPathAndCoordinatesForTouch.get(i2).getViewId(), motionEvent));
                        }
                    }
                } else if (actionMasked == 3) {
                    dispatchCancelEvent(findTargetPathAndCoordinatesForTouch, motionEvent, eventDispatcher);
                } else {
                    FLog.w(ReactConstants.TAG, "Warning : Motion Event was ignored. Action=" + actionMasked + " Target=" + viewId + " Supports Hover=" + supportsHover);
                }
            }
        }
    }

    private int findTargetTagAndSetCoordinates(MotionEvent motionEvent) {
        return TouchTargetHelper.findTargetTagAndCoordinatesForTouch(motionEvent.getX(), motionEvent.getY(), this.mRootViewGroup, this.mTargetCoordinates, null);
    }

    private void handleHoverEvent(MotionEvent motionEvent, EventDispatcher eventDispatcher, int i, List<TouchTargetHelper.ViewTarget> list) {
        if (motionEvent.getActionMasked() == 7) {
            float x = motionEvent.getX();
            float y = motionEvent.getY();
            if (Math.abs(this.mLastEventCoordinates[0] - x) > 1.0f || Math.abs(this.mLastEventCoordinates[1] - y) > 1.0f) {
                if (this.mHoverInteractionKey < 0) {
                    long eventTime = motionEvent.getEventTime();
                    this.mHoverInteractionKey = eventTime;
                    this.mTouchEventCoalescingKeyHelper.addCoalescingKey(eventTime);
                }
                if (this.mChildHandlingNativeGesture > 0) {
                    Iterator<TouchTargetHelper.ViewTarget> it = list.iterator();
                    int i2 = 0;
                    while (true) {
                        if (!it.hasNext()) {
                            break;
                        } else if (it.next().getViewId() == this.mChildHandlingNativeGesture) {
                            list.subList(0, i2).clear();
                            break;
                        } else {
                            i2++;
                        }
                    }
                }
                int viewId = list.isEmpty() ? -1 : list.get(0).getViewId();
                if (viewId != -1) {
                    int i3 = 0;
                    while (i3 < Math.min(list.size(), this.mLastHitPath.size())) {
                        List<TouchTargetHelper.ViewTarget> list2 = this.mLastHitPath;
                        if (!list.get((list.size() - 1) - i3).equals(list2.get((list2.size() - 1) - i3))) {
                            break;
                        }
                        i3++;
                    }
                    if (i3 < Math.max(list.size(), this.mLastHitPath.size())) {
                        this.mTouchEventCoalescingKeyHelper.incrementCoalescingKey(this.mHoverInteractionKey);
                        List<TouchTargetHelper.ViewTarget> subList = list.subList(0, list.size() - i3);
                        if (subList.size() > 0) {
                            int size = subList.size();
                            while (true) {
                                int i4 = size - 1;
                                if (size <= 0) {
                                    break;
                                }
                                eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_ENTER, i, subList.get(i4).getViewId(), motionEvent));
                                size = i4;
                            }
                        }
                        List<TouchTargetHelper.ViewTarget> list3 = this.mLastHitPath;
                        List<TouchTargetHelper.ViewTarget> subList2 = list3.subList(0, list3.size() - i3);
                        if (subList2.size() > 0) {
                            for (TouchTargetHelper.ViewTarget viewTarget : subList2) {
                                eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_LEAVE, i, viewTarget.getViewId(), motionEvent));
                            }
                        }
                    }
                    eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_MOVE, i, viewId, motionEvent, this.mTouchEventCoalescingKeyHelper.getCoalescingKey(this.mHoverInteractionKey)));
                    this.mLastHitPath = list;
                    float[] fArr = this.mLastEventCoordinates;
                    fArr[0] = x;
                    fArr[1] = y;
                }
            }
        }
    }

    private void dispatchCancelEvent(List<TouchTargetHelper.ViewTarget> list, MotionEvent motionEvent, EventDispatcher eventDispatcher) {
        Assertions.assertCondition(this.mChildHandlingNativeGesture == -1, "Expected to not have already sent a cancel for this gesture");
        int surfaceId = UIManagerHelper.getSurfaceId(this.mRootViewGroup);
        if (!list.isEmpty()) {
            ((EventDispatcher) Assertions.assertNotNull(eventDispatcher)).dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_CANCEL, surfaceId, list.get(0).getViewId(), motionEvent));
            for (TouchTargetHelper.ViewTarget viewTarget : list) {
                eventDispatcher.dispatchEvent(PointerEvent.obtain(PointerEventHelper.POINTER_LEAVE, surfaceId, viewTarget.getViewId(), motionEvent));
            }
        }
        this.mTouchEventCoalescingKeyHelper.removeCoalescingKey(this.mDownStartTime);
        this.mDownStartTime = Long.MIN_VALUE;
    }
}
