package expo.modules.securestore;

import android.app.Activity;
import android.content.Context;
import android.os.Build;
import android.util.Log;
import androidx.biometric.BiometricManager;
import androidx.biometric.BiometricPrompt;
import androidx.core.content.ContextCompat;
import androidx.fragment.app.FragmentActivity;
import com.facebook.react.bridge.BaseJavaModule;
import expo.modules.core.ModuleRegistry;
import expo.modules.core.Promise;
import expo.modules.core.arguments.ReadableArguments;
import expo.modules.core.interfaces.ActivityProvider;
import expo.modules.core.interfaces.services.UIManager;
import java.security.GeneralSecurityException;
import javax.crypto.Cipher;
import javax.crypto.spec.GCMParameterSpec;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import org.json.JSONException;

public final class AuthenticationHelper {
    private static final String AUTHENTICATION_PROMPT_PROPERTY;
    public static final Companion Companion = new Companion(null);
    public static final String REQUIRE_AUTHENTICATION_PROPERTY;
    private final Context context;
    private final AuthenticationCallback defaultCallback = new AuthenticationHelper$defaultCallback$1(this);
    private boolean isAuthenticating;
    private final ModuleRegistry moduleRegistry;
    private final UIManager uiManager;

    public AuthenticationHelper(Context context2, ModuleRegistry moduleRegistry2) {
        Intrinsics.checkNotNullParameter(context2, "context");
        Intrinsics.checkNotNullParameter(moduleRegistry2, "moduleRegistry");
        this.context = context2;
        this.moduleRegistry = moduleRegistry2;
        this.uiManager = (UIManager) moduleRegistry2.getModule(UIManager.class);
    }

    public static final /* synthetic */ void access$openAuthenticationPrompt(AuthenticationHelper authenticationHelper, Promise promise, ReadableArguments readableArguments, EncryptionCallback encryptionCallback, Cipher cipher, GCMParameterSpec gCMParameterSpec, PostEncryptionCallback postEncryptionCallback) {
        authenticationHelper.openAuthenticationPrompt(promise, readableArguments, encryptionCallback, cipher, gCMParameterSpec, postEncryptionCallback);
    }

    public static final class Companion {
        public /* synthetic */ Companion(DefaultConstructorMarker defaultConstructorMarker) {
            this();
        }

        private Companion() {
        }
    }

    public final AuthenticationCallback getDefaultCallback() {
        return this.defaultCallback;
    }

    public final void handleEncryptionCallback(Promise promise, EncryptionCallback encryptionCallback, Cipher cipher, GCMParameterSpec gCMParameterSpec, PostEncryptionCallback postEncryptionCallback) {
        Intrinsics.checkNotNullParameter(promise, BaseJavaModule.METHOD_TYPE_PROMISE);
        Intrinsics.checkNotNullParameter(encryptionCallback, "encryptionCallback");
        Intrinsics.checkNotNullParameter(cipher, "cipher");
        Intrinsics.checkNotNullParameter(gCMParameterSpec, "gcmParameterSpec");
        try {
            encryptionCallback.run(promise, cipher, gCMParameterSpec, postEncryptionCallback);
        } catch (GeneralSecurityException e) {
            GeneralSecurityException generalSecurityException = e;
            Log.w("ExpoSecureStore", generalSecurityException);
            promise.reject("ERR_SECURESTORE_ENCRYPT_FAILURE", "Could not encrypt/decrypt the value for SecureStore", generalSecurityException);
        } catch (JSONException e2) {
            JSONException jSONException = e2;
            Log.w("ExpoSecureStore", jSONException);
            promise.reject("ERR_SECURESTORE_ENCODE_FAILURE", "Could not create an encrypted JSON item for SecureStore", jSONException);
        }
    }

    private final void openAuthenticationPrompt(Promise promise, ReadableArguments readableArguments, EncryptionCallback encryptionCallback, Cipher cipher, GCMParameterSpec gCMParameterSpec, PostEncryptionCallback postEncryptionCallback) {
        if (Build.VERSION.SDK_INT < 23) {
            promise.reject("ERR_SECURESTORE_AUTH_NOT_AVAILABLE", "Biometric authentication requires Android API 23");
        } else if (this.isAuthenticating) {
            promise.reject("ERR_SECURESTORE_AUTH_IN_PROGRESS", "Authentication is already in progress");
        } else {
            BiometricManager from = BiometricManager.from(this.context);
            Intrinsics.checkNotNullExpressionValue(from, "from(context)");
            int canAuthenticate = from.canAuthenticate(15);
            if (canAuthenticate != 1) {
                if (canAuthenticate == 11) {
                    promise.reject("ERR_SECURESTORE_AUTH_NOT_CONFIGURED", "No biometrics are currently enrolled");
                    return;
                } else if (canAuthenticate != 12) {
                    BiometricPrompt.PromptInfo build = new BiometricPrompt.PromptInfo.Builder().setTitle(readableArguments.getString(AUTHENTICATION_PROMPT_PROPERTY, " ")).setNegativeButtonText(this.context.getString(17039360)).build();
                    Intrinsics.checkNotNullExpressionValue(build, "Builder()\n      .setTitl…g.cancel))\n      .build()");
                    FragmentActivity fragmentActivity = (FragmentActivity) getCurrentActivity();
                    if (fragmentActivity == null) {
                        promise.reject("ERR_SECURESTORE_APP_BACKGROUNDED", "Cannot display biometric prompt when the app is not in the foreground");
                        return;
                    } else {
                        this.uiManager.runOnUiQueueThread(new AuthenticationHelper$$ExternalSyntheticLambda0(this, fragmentActivity, build, cipher, promise, encryptionCallback, gCMParameterSpec, postEncryptionCallback));
                        return;
                    }
                }
            }
            promise.reject("ERR_SECURESTORE_AUTH_NOT_AVAILABLE", "No hardware available for biometric authentication. Use expo-local-authentication to check if the device supports it.");
        }
    }

    /* renamed from: openAuthenticationPrompt$lambda-0 */
    public static final void m104openAuthenticationPrompt$lambda0(AuthenticationHelper authenticationHelper, FragmentActivity fragmentActivity, BiometricPrompt.PromptInfo promptInfo, Cipher cipher, Promise promise, EncryptionCallback encryptionCallback, GCMParameterSpec gCMParameterSpec, PostEncryptionCallback postEncryptionCallback) {
        Intrinsics.checkNotNullParameter(authenticationHelper, "this$0");
        Intrinsics.checkNotNullParameter(promptInfo, "$promptInfo");
        Intrinsics.checkNotNullParameter(cipher, "$cipher");
        Intrinsics.checkNotNullParameter(promise, "$promise");
        Intrinsics.checkNotNullParameter(encryptionCallback, "$encryptionCallback");
        Intrinsics.checkNotNullParameter(gCMParameterSpec, "$gcmParameterSpec");
        authenticationHelper.isAuthenticating = true;
        new BiometricPrompt(fragmentActivity, ContextCompat.getMainExecutor(authenticationHelper.context), new AuthenticationHelper$openAuthenticationPrompt$1$1(authenticationHelper, promise, encryptionCallback, gCMParameterSpec, postEncryptionCallback)).authenticate(promptInfo, new BiometricPrompt.CryptoObject(cipher));
    }

    private final Activity getCurrentActivity() {
        Object module = this.moduleRegistry.getModule(ActivityProvider.class);
        Intrinsics.checkNotNullExpressionValue(module, "moduleRegistry.getModule…vityProvider::class.java)");
        return ((ActivityProvider) module).getCurrentActivity();
    }
}
